@@ -14,8 +14,8 @@
 #
 
 import copy
-import mock
-from mock import call
+from unittest import mock
+from unittest.mock import call
 
 from magnumclient.exceptions import InvalidAttribute
 from magnumclient.osc.v1 import cluster_templates as osc_ct
@@ -28,7 +28,7 @@ class TestClusterTemplate(magnum_fakes.TestMagnumClientOSCV1):
     default_create_args = {
         'coe': 'kubernetes',
         'dns_nameserver': '8.8.8.8',
-        'docker_storage_driver': 'devicemapper',
+        'docker_storage_driver': 'overlay2',
         'docker_volume_size': None,
         'external_network_id': 'public',
         'fixed_network': None,
@@ -225,12 +225,15 @@ class TestClusterTemplateList(TestClusterTemplate):
 
     columns = [
         'uuid',
-        'name'
+        'name',
+        'tags',
     ]
 
     datalist = (
-        (_cluster_template.uuid, _cluster_template.name),
-        (_cluster_template2.uuid, _cluster_template2.name)
+        (_cluster_template.uuid, _cluster_template.name,
+         _cluster_template.tags),
+        (_cluster_template2.uuid, _cluster_template2.name,
+         _cluster_template.tags)
     )
 
     def setUp(self):
@@ -271,22 +274,24 @@ class TestClusterTemplateList(TestClusterTemplate):
             '--limit', '1',
             '--sort-key', 'key',
             '--sort-dir', 'asc',
-            '--fields', 'fields'
+            '--fields', 'field1,field2'
         ]
         verifylist = [
             ('limit', 1),
             ('sort_key', 'key'),
             ('sort_dir', 'asc'),
-            ('fields', 'fields'),
+            ('fields', 'field1,field2'),
         ]
+        verifycolumns = self.columns + ['field1', 'field2']
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        self.cmd.take_action(parsed_args)
+        columns, data = self.cmd.take_action(parsed_args)
         self.cluster_templates_mock.list.assert_called_with(
             limit=1,
             sort_dir='asc',
             sort_key='key',
         )
+        self.assertEqual(verifycolumns, columns)
 
     def test_cluster_template_list_bad_sort_dir_fail(self):
         arglist = [
